    Mac OS X            	   2                                              ATTR            D                     *  $com.apple.metadata:_kMDItemUserTags          com.dropbox.attrs    bplist00                            	

vaB      ĵ	